----------------
-- RuneHenge --
----------------

RuneHenge = Henge:NewModule("RuneHenge")
RuneHenge.fullname = "RuneHenge"
RuneHenge.icon     = "icon"
local ML, SL = nil, nil, nil

function RuneHenge:Test()
	local _, pClass = UnitClass("player")
	return (pClass == "MAGE")
end

function RuneHenge:Load()
	ML = HengeLocale:LoadRuneHenge()
	SL = AceLibrary("Babble-Spell-2.2")
	-- Set up variables
	self:SetupDB({
		["profile"] = {
		},
		["char"] = {}
	})
	if UnitFactionGroup("player") == "Alliance" then
		Teleport1 = "Teleport: Ironforge"
		Teleport2 = "Teleport: Stormwind"
		Teleport3 = "Teleport: Darnassus"
		Teleport4 = "Teleport: Exodar"
		Teleport5 = "Teleport: Shattrath"
		Portal1 = "Portal: Ironforge"
		Portal2 = "Portal: Stormwind"
		Portal3 = "Portal: Darnassus"
		Portal4 = "Portal: Exodar"
		Portal5 = "Portal: Shattrath"
	else
		Teleport1 = "Teleport: Orgrimmar"
		Teleport2 = "Teleport: Undercity"
		Teleport3 = "Teleport: Thunder Bluff"
		Teleport4 = "Teleport: Silvermoon"
		Teleport5 = "Teleport: Shattrath"
		Portal1 = "Portal: Orgrimmar"
		Portal2 = "Portal: Undercity"
		Portal3 = "Portal: Thunder Bluff"
		Portal4 = "Portal: Silvermoon"
		Portal5 = "Portal: Shattrath"
	end
	local spell = {
	-- Teleport
		["tele1"]  			=     			SL[Teleport1],
		["tele2"]  			=     			SL[Teleport2],
		["tele3"] 			=     			SL[Teleport3],
		["tele4"] 			=     			SL[Teleport4],
		["tele5"] 			=     			SL[Teleport5],
	-- Portals
		["port1"]  			=     			  SL[Portal1],
		["port2"]  			=     			  SL[Portal2],
		["port3"] 			=     			  SL[Portal3],
		["port4"] 			=     			  SL[Portal4],
		["port5"] 			=     			  SL[Portal5],
	-- Armor Buffs
		["icearmor"]        =             SL["Ice Armor"],
		["magearmor"]       =            SL["Mage Armor"],
	-- Intellect Buffs
		["arcaneintel"]     =      SL["Arcane Intellect"],
		["arcanebrill"]     =     SL["Arcane Brilliance"],
	-- Buffs
		["dampen"]     		=          SL["Dampen Magic"],
		["amplify"]    		=         SL["Amplify Magic"],
	-- Wards
		["fireward"]     	=             SL["Fire Ward"],
		["frostward"]    	=            SL["Frost Ward"],
	-- Evocation
		["evoc"]            =             SL["Evocation"],
	-- Shields
		["manashield"]     	=      		SL["Mana Shield"],
		["icebarrier"]     	=      		SL["Ice Barrier"],
	-- Conjure Water/Food
		["cwater"]     		=      	  SL["Conjure Water"],
		["cfood"]     		=      	   SL["Conjure Food"],
	-- Conjure Gem
		["cmanagem1"] 		=     SL["Conjure Mana Ruby"],
		["cmanagem2"] 		=  SL["Conjure Mana Citrine"],
		["cmanagem3"] 		=     SL["Conjure Mana Jade"],
		["cmanagem4"] 		=    SL["Conjure Mana Agate"],
	-- Slowfall
		["slowfall"]    	=             SL["Slow Fall"],
	}
	for k, v in pairs(spell) do
		HengeAction:Add({
			["id"] = k,
			["type"] = 'spell',
			["name"] = v,
			["spell"] = v
		})
	end

	HengeSphere:AddData({
		["id"]   = "mana",
		["name"] = ML["Mana"],
		["func"] = function()
			return UnitMana("player"), UnitManaMax("player")
		end,
		["event"] = "UNIT_MANA",
		["arg1"] = "player"
	})

	local data = {
		{
			["id"]     = "teleport",
			["name"]   = ML["Teleport"],
			["opt"]    ="tele1",
			["pos"]    = 122,
			["desc"]   = ML["Change teleport to cast."],
			["icon"] = "child:tele1",
			["menu"] = {
				[1] = "tele1",
				[2] = "tele2",
				[3] = "tele3",
				[4] = "tele4",
				[5] = "tele5",
			}
		},
		{
			["id"]     = "portal",
			["name"]   = ML["Portal"],
			["opt"]    = "port1",
			["pos"]    = 154,
			["desc"]   = ML["Change portal to cast."],
			["icon"] = "child:port1",
			["menu"] = {
				[1] = "port1",
				[2] = "port2",
				[3] = "port3",
				[4] = "port4",
				[5] = "port5",
			}
		},
		{
			["id"]     = "cmanagem",
			["name"]   = ML["Conjure Gem"],
			["opt"]    = "cmanagem1",
			["pos"]    = -144,
			["desc"]   = ML["Change gem to cast."],
			["icon"] = "child:cmanagem1",
			["menu"] = {
				[1] = "cmanagem1",
				[2] = "cmanagem2",
				[3] = "cmanagem3",
				[4] = "cmanagem4",
			}
		},
	}
	for k, v in ipairs(data) do
		local bdata = {
			["id"]   = v.id,
			["type"] = "menu",
			["name"] = v.name,
			["desc"] = v.desc,
			["icon"] = v.icon,
			["ltype"] = "spell",
			["lval"] = v.menu[1],
			["children"] = {},
			["options"] = {
				["anchor"] = "sphere:Main",
				["xpos"] = 0,
				["ypos"] = 0,
				["angle"] = v.pos
			}
		}
		for num, id in ipairs(v.menu) do
			local action = HengeAction:Get(id)
			local name, desc, icon = action:ActionInfo()
			bdata.children[num] = {
				["id"] = id,
				["name"] = name,
				["icon"] = "action:LeftButton",
				["actions"] = {
					["LeftButton"] = id
				},
				["options"] = {
				}
			}
		end
		HengeButton:Add(bdata)
	end

	HengeButton:Add({
		["id"]   = "armorbuffs",
		["type"] = "action",
		["name"] = ML["Armor Buffs"],
		["icon"] = "action:LeftButton",
		["actions"] = {
			["LeftButton"] = "icearmor",
			["RightButton"] = "magearmor"
		},
		["options"] = {
			["anchor"] = "sphere:Main",
			["xpos"] = 0,
			["ypos"] = 0,
			["angle"] = 60
		}
	})
	HengeButton:Add({
		["id"]   = "intelbuffs",
		["type"] = "action",
		["name"] = ML["Intellect Buffs"],
		["icon"] = "action:LeftButton",
		["actions"] = {
			["LeftButton"] = "arcaneintel",
			["RightButton"] = "arcanebrill"
		},
		["options"] = {
			["anchor"] = "sphere:Main",
			["xpos"] = 0,
			["ypos"] = 0,
			["angle"] = 30
		}
	})
	HengeButton:Add({
		["id"]   = "buffs",
		["type"] = "action",
		["name"] = ML["Buffs"],
		["icon"] = "action:LeftButton",
		["actions"] = {
			["LeftButton"] = "dampen",
			["RightButton"] = "amplify"
		},
		["options"] = {
			["anchor"] = "sphere:Main",
			["xpos"] = 0,
			["ypos"] = 0,
			["angle"] = -2
		}
	})
	HengeButton:Add({
		["id"]   = "wards",
		["type"] = "action",
		["name"] = ML["Wards"],
		["icon"] = "action:LeftButton",
		["actions"] = {
			["LeftButton"] = "fireward",
			["RightButton"] = "frostward"
		},
		["options"] = {
			["anchor"] = "sphere:Main",
			["xpos"] = 0,
			["ypos"] = 0,
			["angle"] = -69
		}
	})
	HengeButton:Add({
		["id"]   = "evoc",
		["type"] = "action",
		["name"] = ML["Evocation"],
		["icon"] = "action:LeftButton",
		["actions"] = {
			["LeftButton"] = "evoc",
		},
		["options"] = {
			["anchor"] = "sphere:Main",
			["xpos"] = 0,
			["ypos"] = 0,
			["angle"] = 91
		}
	})
	HengeButton:Add({
		["id"]   = "shields",
		["type"] = "action",
		["name"] = ML["Shields"],
		["icon"] = "action:LeftButton",
		["actions"] = {
			["LeftButton"] = "manashield",
			["RightButton"] = "icebarrier"
		},
		["options"] = {
			["anchor"] = "sphere:Main",
			["xpos"] = 0,
			["ypos"] = 0,
			["angle"] = -34
		}
	})
	HengeButton:Add({
		["id"]   = "conjure",
		["type"] = "action",
		["name"] = ML["Conjure Water/Food"],
		["icon"] = "action:LeftButton",
		["actions"] = {
			["LeftButton"] = "cwater",
			["RightButton"] = "cfood"
		},
		["options"] = {
			["anchor"] = "sphere:Main",
			["xpos"] = 0,
			["ypos"] = 0,
			["angle"] = -175
		}
	})
	HengeButton:Add({
		["id"]   = "slowfall",
		["type"] = "action",
		["name"] = ML["Slowfall"],
		["icon"] = "action:LeftButton",
		["actions"] = {
			["LeftButton"] = "slowfall",
		},
		["options"] = {
			["anchor"] = "sphere:Main",
			["xpos"] = 0,
			["ypos"] = 0,
			["angle"] = -109
		}
	})
end
